#Chapter 11: Ability data example

#Reading the covariance matrix
lower <- '
135.97 
89.21 130.94
94.15 96.42 147.69
94.36 98.54 112.11 137.10
127.47 96.03 104.27 100.72 211.26
97.90 83.74 88.67 91.27 107.89 129.98 
65.43 77.44 71.12 77.25 69.21 68.31 85.03
112.23 113.82 137.43 135.58 115.87 116.16 94.84 214.35
88.54 93.03 106.11 120.17 94.96 91.01 76.31 141.02 135.09 
100.70 79.67 85.93 87.23 128.99 99.87 68.39 110.71 88.00 154.27'

#Assigning names to the variables
ability.cov <- 
    getCov(lower, names = c("math9","sci9","read9","scatv9","scatq9",
                            "math7","sci7","read7","scatv7","scatq7"))

#Defining the model (measurement and structural) given in Figure 11.6
ability.model1 <- '
  # latent variables
    quant7  =~ scatq7+math7+sci7
    quant9 =~ scatq9+math9+sci9
    verbal7=~ scatv7+sci7+read7
    verbal9=~ scatv9+sci9+read9

  # regressions
    quant9 ~ quant7
    verbal9 ~ verbal7
'

#Fitting the model that appears in Figure 11.6
fit <- sem(ability.model1, 
           sample.cov = ability.cov, 
           sample.nobs = 383, estimator="GLS")
summary(fit, standardized = TRUE)

#Computing modification indices
mi <- modindices(fit)
mi[mi$op == "=~",]

#Defining the model (measurement and structural) given in Figure 11.7
ability.model2 <- '
  # latent variables
    quant7  =~ scatq7+math7+sci7
    quant9 =~ scatq9+math9+sci9
    verbal7=~ scatv7+sci7+read7
    verbal9=~ scatv9+sci9+read9

  # regressions
    quant9 ~ quant7
    verbal9 ~ verbal7 + quant9

  # correlated residuals
     math9 ~~ math7
     sci9 ~~ sci7
     read9 ~~ read7
     scatv9 ~~ scatv7
     scatq9 ~~ scatq7
  
Verbal7 with Verbal9 @ 0;
 Quant7 with Quant9 @ 0;
 Verbal9 with Quant9 @ 0;
 
'

#Fitting the model that appears in Figure 11.7
fit <- sem(ability.model2, 
           sample.cov = ability.cov, 
           sample.nobs = 383, estimator="GLS")
summary(fit, standardized = TRUE)

